import numpy as np

arcsec_in_radian = 1 / 3600 / 180 * np.pi
arcsec_in_degrees = 1 / 3600

degrees_in_arcsec = 3600
radian_in_arcsec = 3600 * 180 * np.pi

uradian_in_arcsec = (3600 * 180) / 1e6 / np.pi
